==> egg-axios-plus-1.0.1.tgz: package/README.md <==
# egg-axios-plus

[![NPM version][npm-image]][npm-url]
[![build status][travis-image]][travis-url]
[![Test coverage][codecov-image]][codecov-url]
[![David deps][david-image]][david-url]
[![Known Vulnerabilities][snyk-image]][snyk-url]
[![npm download][download-image]][download-url]

[npm-image]: https://img.shields.io/npm/v/egg-axios-plus.svg?style=flat-square
[npm-url]: https://npmjs.org/package/egg-axios-plus
[travis-image]: https://img.shields.io/travis/eggjs/egg-axios-plus.svg?style=flat-square
[travis-url]: https://travis-ci.org/eggjs/egg-axios-plus
[codecov-image]: https://img.shields.io/codecov/c/github/eggjs/egg-axios-plus.svg?style=flat-square
[codecov-url]: https://codecov.io/github/eggjs/egg-axios-plus?branch=master
[david-image]: https://img.shields.io/david/eggjs/egg-axios-plus.svg?style=flat-square
[david-url]: https://david-dm.org/eggjs/egg-axios-plus
[snyk-image]: https://snyk.io/test/npm/egg-axios-plus/badge.svg?style=flat-square
[snyk-url]: https://snyk.io/test/npm/egg-axios-plus
[download-image]: https://img.shields.io/npm/dm/egg-axios-plus.svg?style=flat-square
[download-url]: https://npmjs.org/package/egg-axios-plus

<!--
Description here.
-->

## Install

```bash
$ npm i egg-axios-plus --save
```

## Usage

```js
// {app_root}/config/plugin.js
exports.axios = {
  enable: true,
  package: 'egg-axios-plus',
};
```

## Configuration

```js
// {app_root}/config/config.default.js
exports.axios = {
};
```

see [config/config.default.js](config/config.default.js) for more detail.

## Example

<!-- example here -->

## Questions & Suggestions

Please open an issue [here](https://github.com/eggjs/egg/issues).

## License

[MIT](LICENSE)

==> egg-axios-plus-1.1.1.tgz: package/README.md <==
# egg-axios-plus

[![NPM version][npm-image]][npm-url]
[![build status][travis-image]][travis-url]
[![Test coverage][codecov-image]][codecov-url]
[![David deps][david-image]][david-url]
[![Known Vulnerabilities][snyk-image]][snyk-url]
[![npm download][download-image]][download-url]

[npm-image]: https://img.shields.io/npm/v/egg-axios-plus.svg?style=flat-square
[npm-url]: https://npmjs.org/package/egg-axios-plus
[travis-image]: https://img.shields.io/travis/eggjs/egg-axios-plus.svg?style=flat-square
[travis-url]: https://github.com/mmdapl/egg-axios-plus
[codecov-image]: https://img.shields.io/codecov/c/github/eggjs/egg-axios-plus.svg?style=flat-square
[codecov-url]: https://codecov.io/github/eggjs/egg-axios-plus?branch=master
[david-image]: https://img.shields.io/david/eggjs/egg-axios-plus.svg?style=flat-square
[david-url]: https://david-dm.org/eggjs/egg-axios-plus
[snyk-image]: https://snyk.io/test/npm/egg-axios-plus/badge.svg?style=flat-square
[snyk-url]: https://snyk.io/test/npm/egg-axios-plus
[download-image]: https://img.shields.io/npm/dm/egg-axios-plus.svg?style=flat-square
[download-url]: https://npmjs.org/package/egg-axios-plus

<!--
Description here.
-->

## Install

```bash
$ npm i egg-axios-plus --save
```

## Usage

```js
// {app_root}/config/plugin.js
exports.axios = {
  enable: true,
  package: 'egg-axios-plus',
};
```

## Configuration

```js
// {app_root}/config/config.default.js
exports.axios = {
    headers: {
    common: {
      'Content-Type': 'application/json; charset=UTF-8',
    },
  },
  timeout: 5000,
};
```

see [config/config.default.js](config/config.default.js) for more detail.

## Example

<!-- example here -->

## Questions & Suggestions

Please open an issue [here](https://github.com/mmdapl/egg-axios-plus).

## License

[MIT](LICENSE)
